<h1 align="center">
<img src="logo.png" height="150">
</h1><br>

Manzara is a Python (>=3.12) package for simulating and analyzing fitness landscapes.
It's designed in terms of three main classes: sequences (`manzara.Seq`), sequence spaces (`manzara.Space`), and fitness landscapes (`manzara.FitnessLandscape`), the last of which is the superclass of specific fitness landscape models.
See [demo.ipynb](demo.ipynb) for more.
To install, run `pip install manzara` at the command line.
Feel free to make pull requests if you'd like to contribute e.g. new models or landscape properties.
